@@ -1,12 +1,18 @@
 using Test
 using PrettyTables
 
+using Crayons
 using LaTeXStrings
 using Markdown
 using OffsetArrays
 using StyledStrings
 using Tables
 
+# Force color output for tests to ensure ANSI escape codes are generated.
+# This is needed because Crayons.jl may disable colors during precompilation or
+# in non-TTY environments like CI.
+Crayons.force_color(true)
+
 ############################################################################################
 #                                   Types and Structures                                   #
 ############################################################################################
@@ -88,6 +94,21 @@ end
     include("./backends/text/special_cells.jl")
 end
 
+@testset "Typst Back End Tests" verbose = true begin
+    include("./backends/typst/alignment.jl")
+    include("./backends/typst/caption.jl")
+    include("./backends/typst/circular_reference.jl")
+    include("./backends/typst/data_column_widths.jl")
+    include("./backends/typst/cropping.jl")
+    include("./backends/typst/decorations.jl")
+    include("./backends/typst/default.jl")
+    include("./backends/typst/full.jl")
+    include("./backends/typst/highlighters.jl")
+    include("./backends/typst/offset_arrays.jl")
+    include("./backends/typst/renderers.jl")
+    include("./ext/pretty_tables_typstry_ext.jl")
+end
+
 @testset "Tables.jl" verbose = true begin
     include("./tables.jl")
 end
